@@ -3,6 +3,8 @@ import json
 
 
 def error_handler(response):
+    if response.status_code == 204:
+        return "Job not found"
     print(f"Status: {response.status_code}")
     print(f"ErrorMessage: {response.json()['error']}")
     return {response.json()['error']}
@@ -149,12 +151,11 @@ def delete(userID: str, id: str):
         "email": userID,
     }
     response = requests.delete(f"{url_path}", headers=headers)
+    
     if response.status_code != 200:
         return error_handler(response)
 
     print(f"Deleted job : {response.text}")
 
-    if response.text == "":
-        print("Job not found.")
     return response.text
 
